@@ -13,29 +13,6 @@ let package = Package(
     .target(
       name: "TreeSitterPHP",
       path: ".",
-      exclude: [
-        "Cargo.toml",
-        "Makefile",
-        "binding.gyp",
-        "bindings/c",
-        "bindings/go",
-        "bindings/node",
-        "bindings/python",
-        "bindings/rust",
-        "prebuilds",
-        "grammar.js",
-        "package.json",
-        "package-lock.json",
-        "pyproject.toml",
-        "setup.py",
-        "test",
-        "examples",
-        ".editorconfig",
-        ".github",
-        ".gitignore",
-        ".gitattributes",
-        ".gitmodules",
-      ],
       sources: [
         "php/src/parser.c",
         "php/src/scanner.c",
